WriteToLpFileFormat

Trait WriteToLpFileFormat 

pub trait WriteToLpFileFormat {
    // Required method
    fn to_lp_file_format(&self, f: &mut Formatter<'_>) -> Result;
}
It’s the user’s responsibility to ensure that the variable names used by types implementing this trait follow the solver’s requirements.

Required Methods

fn to_lp_file_format(&self, f: &mut Formatter<'_>) -> Result

Write the object to the given formatter in the .lp format

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: WriteToLpFileFormat> WriteToLpFileFormat for &T

Source

fn to_lp_file_format(&self, f: &mut Formatter<'_>) -> Result

Implementors