Module lp_solvers::problem [−][src]
Concrete implementations for the traits in crate::lp_format
Structs
| Problem | A concrete linear problem |
| StrExpression | A string that is a valid expression in the .lp format for the solver you are using |
| Variable | A variable to optimize |