Struct lp_solvers::problem::Variable[][src]

pub struct Variable {
    pub name: String,
    pub is_integer: bool,
    pub lower_bound: f64,
    pub upper_bound: f64,
}

A variable to optimize

Fields

name: String

The variable name should be unique in the problem and have a name accepted by the solver

is_integer: bool

Whether the variable is restricted to only integer values

lower_bound: f64

-INFINITY if there is no lower bound

upper_bound: f64

INFINITY if there is no upper bound