Trait lp_solvers::lp_format::LpProblem [−][src]
Implemented by type that can be formatted as an lp problem
Associated Types
type Variable: AsVariable[src]
variable type
type Expression: WriteToLpFileFormat[src]
expression type
type ConstraintIterator: Iterator<Item = Constraint<Self::Expression>>[src]
Iterator over constraints
type VariableIterator: Iterator<Item = Self::Variable>[src]
Iterator over variables
Required methods
fn variables(&'a self) -> Self::VariableIterator[src]
Variables of the problem
fn objective(&'a self) -> Self::Expression[src]
Target objective function
fn sense(&'a self) -> LpObjective[src]
Whether to maximize or minimize the objective
fn constraints(&'a self) -> Self::ConstraintIterator[src]
List of constraints to apply
Provided methods
fn name(&self) -> &str[src]
problem name. “lp_solvers_problem” by default
fn to_lp_file_format(&'a self, f: &mut Formatter<'_>) -> Result[src]
Write the problem in the lp file format to the given formatter
fn display_lp(&'a self) -> DisplayedLp<'_, Self> where
Self: Sized, [src]
Self: Sized,
Return an object whose fmt::Display implementation is the problem in the .lp format
fn to_tmp_file(&'a self) -> Result<NamedTempFile> where
Self: Sized, [src]
Self: Sized,
Write the problem to a temporary file
Implementors
impl<'a, EXPR: 'a, VAR: 'a> LpProblem<'a> for Problem<EXPR, VAR> where
&'a VAR: AsVariable,
&'a EXPR: WriteToLpFileFormat, [src]
&'a VAR: AsVariable,
&'a EXPR: WriteToLpFileFormat,