Trait lp_solvers::lp_format::WriteToLpFileFormat [−][src]
It’s the user’s responsibility to ensure that the variable names used by types implementing this trait follow the solver’s requirements.
Required methods
fn to_lp_file_format(&self, f: &mut Formatter<'_>) -> Result[src]
Write the object to the given formatter in the .lp format